.. _api:

API reference
-------------

This page provides an auto-generated summary of Xbatcher's API.

Core
====

.. autoclass:: xbatcher.BatchGenerator
   :members:

Dataset.batch and DataArray.batch
=================================

.. currentmodule:: xarray

.. autosummary::
   :toctree: generated/
   :template: autosummary/accessor_method.rst

   Dataset.batch.generator
   DataArray.batch.generator
